==> tdf?file=1&path=frealign_v8.11_130826.tar.gz: frealign_v8.11/src/shiftvol.f <==
C -----------------------------------------------------------------------------
	SUBROUTINE SHIFTVOL(NSAM,STD,VTD,JC,RLIM,NSAMH,IREDUN,
     +                      A3DS,D3DS,
     +			    A3DF,D3DF,S3DS,V3DS,S3DF,V3DF,ASUM,
     +                      QCP,NNSTAT,
     +                      IFSC,PSSNR,FPART)
C -----------------------------------------------------------------------------
C       SHIFT VOLUME INTO CENTRE
C       Used in Frealign.
C -----------------------------------------------------------------------------
        IMPLICIT NONE
        INTEGER L,LL,M,MM,N,NN,JC,NSAM,WC1,NSAMH,IS,ID
        INTEGER NUTD,ISUM,IREDUN,JRAD2,IRREC2,NNSTAT,IFSC,I
        REAL    PSHFTR,UTD,TMP,RLIM,FPART
	DOUBLEPRECISION STD,VTD
	COMPLEX A3DF(*),D3DF(*)
	COMPLEX A3DS(*),D3DS(*)
	REAL    S3DF(*),V3DF(*),QCP(*),PSSNR(*)
	REAL    S3DS(*),V3DS(*),ASUM(*)
C -----------------------------------------------------------------------------
        STD=STD+VTD
        IRREC2=(INT(REAL(NSAM)*RLIM))**2
        DO 61 L=1,JC
          LL=L-1
          DO 61 M=1,NSAM
            MM=M-1
            IF (MM.GE.JC) MM=MM-NSAM
            DO 61 N=1,NSAM
              NN=N-1
              IF (NN.GE.JC) NN=NN-NSAM
              JRAD2=LL**2+MM**2+NN**2
              ISUM=(LL+MM+NN)
              PSHFTR=1.0
              IF (MOD(ISUM,2).NE.0) PSHFTR=-1.0
              I=INT(SQRT(REAL(LL**2+MM**2+NN**2))+0.5)+1
              IF (L.NE.JC) THEN
                ID=L+NSAMH*((M-1)+NSAM*(N-1))
                IF (IFSC.EQ.0) THEN
                  A3DF(ID)=A3DF(ID)+D3DF(ID)
                  IF (NNSTAT.NE.0) THEN
                    IF (QCP(ID).NE.0.0) THEN
                      TMP=ASUM(ID)/QCP(ID)-1.0
                    ELSE
                      TMP=0.0
                    ENDIF
                    IF (TMP.GT.0.0) THEN
                      D3DF(ID)=CMPLX(TMP,0.0)*PSHFTR
                    ELSE
                      D3DF(ID)=CMPLX(0.0,0.0)
                    ENDIF
                  ENDIF
                  S3DF(ID)=S3DF(ID)+V3DF(ID)
                ENDIF
                IF(JRAD2.LE.IRREC2) THEN
                  IF (FPART.EQ.0.0) THEN
                    A3DF(ID)=A3DF(ID)*PSHFTR/(S3DF(ID)+STD*IREDUN)
                  ELSEIF (PSSNR(I).NE.0.0) THEN
                    A3DF(ID)=A3DF(ID)*PSHFTR/(S3DF(ID)+1.0/PSSNR(I))
                  ELSE
                    A3DF(ID)=CMPLX(0.0,0.0)
                  ENDIF
                ELSE
                  A3DF(ID)=CMPLX(0.0,0.0)
                ENDIF
              ELSE
                IS=M+NSAM*(N-1)
                IF (IFSC.EQ.0) THEN
                  A3DS(IS)=A3DS(IS)+D3DS(IS)
                  D3DS(IS)=CMPLX(0.0,0.0)
                  S3DS(IS)=S3DS(IS)+V3DS(IS)
                ENDIF
                IF(JRAD2.LE.IRREC2) THEN
                  IF (FPART.EQ.0.0) THEN
                    A3DS(IS)=A3DS(IS)*PSHFTR/(S3DS(IS)+STD*IREDUN)
                  ELSEIF (PSSNR(I).NE.0.0) THEN
                    A3DS(IS)=A3DS(IS)*PSHFTR/(S3DF(IS)+1.0/PSSNR(I))
                  ELSE
                    A3DS(IS)=CMPLX(0.0,0.0)
                  ENDIF
                ELSE
                  A3DS(IS)=CMPLX(0.0,0.0)
                ENDIF
              ENDIF
61      CONTINUE
	RETURN
	END

==> tdf?file=1&path=frealign_v9.05_131002.tar.gz: frealign_v9.05/src/shiftvol.f <==
C*
C* Copyright 2013 Howard Hughes Medical Institute.
C* All rights reserved.
C* Use is subject to Janelia Farm Research Campus Software Copyright 1.1
C* license terms ( http://license.janelia.org/license/jfrc_copyright_1_1.html )
C*
C -----------------------------------------------------------------------------
	SUBROUTINE SHIFTVOL(NSAM,STD,VTD,JC,RLIM,NSAMH,NN1,
     +                      IREDUN,A3DS,D3DS,
     +			    A3DF,D3DF,S3DS,V3DS,S3DF,V3DF,
     +                      ASUM,QCP,NNSTAT,IFSC)
C -----------------------------------------------------------------------------
C       SHIFT VOLUME INTO CENTRE
C       Used in Frealign.
C -----------------------------------------------------------------------------
        IMPLICIT NONE
        INTEGER NN1,L,LL,M,MM,N,NN,JC,NSAM,WC1,NSAMH,IS,ID
        INTEGER NUTD,ISUM,IREDUN,JRAD2,IRREC2,NNSTAT,IFSC
        REAL    PSHFTR,UTD,TMP,RLIM
	DOUBLEPRECISION STD,VTD
	COMPLEX A3DF(*),D3DF(*)
	COMPLEX A3DS(*),D3DS(*)
	REAL    S3DF(*),V3DF(*),QCP(*)
	REAL    S3DS(*),V3DS(*),ASUM(*)
C -----------------------------------------------------------------------------
        STD=STD+VTD
        IRREC2=(INT(REAL(NSAM)*RLIM))**2
        DO 61 L=1,JC
          LL=L-1
          DO 61 M=1,NSAM
            MM=M-1
            IF (MM.GE.JC) MM=MM-NSAM
            DO 61 N=1,NSAM
              NN=N-1
              IF (NN.GE.JC) NN=NN-NSAM
              JRAD2=LL**2+MM**2+NN**2
              ISUM=(LL+MM+NN)
              PSHFTR=1.0
              IF (MOD(ISUM,2).NE.0) PSHFTR=-1.0
              IF (L.NE.JC) THEN
                ID=L+NSAMH*((M-1)+NSAM*(N-1))
                IF (IFSC.EQ.0) THEN
                  A3DF(ID)=A3DF(ID)+D3DF(ID)
                  IF (NNSTAT.NE.0) THEN
                    IF (QCP(ID).NE.0.0) THEN
                      TMP=ASUM(ID)/QCP(ID)-1.0
                    ELSE
                      TMP=0.0
                    ENDIF
                    IF (TMP.GT.0.0) THEN
                      D3DF(ID)=CMPLX(TMP,0.0)*PSHFTR
                    ELSE
                      D3DF(ID)=CMPLX(0.0,0.0)
                    ENDIF
                  ENDIF
                  S3DF(ID)=S3DF(ID)+V3DF(ID)
                ENDIF
                IF(JRAD2.LE.IRREC2) THEN
                  A3DF(ID)=A3DF(ID)*PSHFTR/(S3DF(ID)+STD*IREDUN)
                ELSE
                  A3DF(ID)=CMPLX(0.0,0.0)
                ENDIF
              ELSE
                IS=M+NSAM*(N-1)
                IF (IFSC.EQ.0) THEN
                  A3DS(IS)=A3DS(IS)+D3DS(IS)
                  D3DS(IS)=CMPLX(0.0,0.0)
                  S3DS(IS)=S3DS(IS)+V3DS(IS)
                ENDIF
                IF(JRAD2.LE.IRREC2) THEN
                  A3DS(IS)=A3DS(IS)*PSHFTR/(S3DS(IS)+STD*IREDUN)
                ELSE
                  A3DS(IS)=CMPLX(0.0,0.0)
                ENDIF
              ENDIF
61      CONTINUE
	RETURN
	END
